#include <stdio.h>
#include <stdlib.h>

#define DEGEN 6
#define MAXN 100000

typedef struct nbr
{
  unsigned who;
  struct nbr *next;
} nbr;

static unsigned n;
static nbr *nbrs[MAXN];

static void
add_edge (unsigned f, unsigned t)
{
  nbr *a = malloc (sizeof (nbr));
  a->who = t;
  a->next = nbrs[f];
  nbrs[f] = a;
}

static int
cmpu (const void *a, const void *b)
{
  unsigned va = *(unsigned *) a;
  unsigned vb = *(unsigned *) b;
  return va - vb;
}

static void
sort_list (nbr *l)
{
  nbr *a;
  unsigned *lelts, n = 0;

  for (a = l; a; a = a->next)
    n++;
  lelts = malloc (n * sizeof (unsigned));
  n = 0;
  for (a = l; a; a = a->next)
    lelts[n++] = a->who;
  qsort (lelts, n, sizeof (unsigned), cmpu);
  n = 0;
  for (a = l; a; a = a->next)
    a->who = lelts[n++];
  free (lelts);
}

static void
print_list (nbr *l)
{
  const char *sep = "";
  
  for (; l; l = l->next)
    {
      printf ("%s%d", sep, l->who + 1);
      sep = " ";
    }
  printf ("\n");
}

static void
free_list (nbr *l)
{
  nbr *a;

  while (l)
    {
      a = l->next;
      free (l);
      l = a;
    }
}

static nbr *
intersect (nbr *la, nbr *lb)
{
  nbr *ret, **eret = &ret;

  while (la && lb)
    {
      if (la->who < lb->who)
	la = la->next;
      else if (la->who > lb->who)
	lb = lb->next;
      else
	{
	  nbr *nw = malloc (sizeof (nbr));
	  nw->who = la->who;
	  *eret = nw;
	  eret = &nw->next;
	  la = la->next;
	  lb = lb->next;
	}
    }
  *eret = NULL;
  return ret;
}

typedef struct
{
  unsigned size;
  nbr *members;
} klika;

static klika
max_subklika (nbr *lst)
{
  klika act, ret;

  ret.members = NULL;
  ret.size = 0;

  for (; lst; lst = lst->next)
    {
      unsigned a = lst->who;
      nbr *possible = intersect (lst->next, nbrs[a]);
      act = max_subklika (possible);
      if (act.size >= ret.size)
	{
	  nbr *am;
	  free_list (ret.members);
	  ret = act;
	  am = malloc (sizeof (nbr));
	  am->who = a;
	  am->next = ret.members;
	  ret.members = am;
	  ret.size++;
	}
    }

  return ret;
}

int main (void)
{
  int m, i;
  klika ret, act;
  nbr *cand;

  scanf ("%u%d", &n, &m);
  for (i = 0; i < m; i++)
    {
      unsigned x, y;
      scanf ("%u%u", &x, &y);
      x--; y--;
      add_edge (x, y);
      add_edge (y, x);
    }

  for (i = 0; i < n; i++)
    sort_list (nbrs[i]);
  ret.members = NULL;
  ret.size = 0;
  for (i = 0; i < n; i++)
    {
      act = max_subklika (nbrs[i]);
      if (act.size >= ret.size)
	{
	  free_list (ret.members);
	  ret = act;
	  ret.size++;
	  cand = malloc (sizeof (nbr));
	  cand->who = i;
	  cand->next = ret.members;
	  ret.members = cand;
	}
    }

  print_list (ret.members);

  return 0;
}
